# Release 0.2.0 - Tuesday 21 June  07:37:22 AEST 2016

- Support wheels
- Ensure HTML is prettified to remove whitespace differences to get around issues in travis/circleci.
- Allow failure of pypy3 in travis
- Removed incorrectly added file
- Added pypy3 to travis config
- Added templates to MANIFEST and package_data
- Testing all supported environments with tox.
- Docs (with readthedocs support).
- Python 3 now supported.
- Ignore direnv files
- Updated git-tools and added git-tools-hook.
- Added version info to root __init__.py
- Fix setup.py to install via pip

# Release 0.1.0 - Thu Nov 20 12:45:03 EST 2014

- Initial release


